<?php declare(strict_types=1);

namespace App\Controller;

use App\Repository\TopicRepository;
use App\Service\QuestionService;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\Routing\Annotation\Route;

/**
 * Class MainController
 * @package App\Controller
 */
class MainController extends AbstractController
{
    private TopicRepository $topicRepository;

    private QuestionService $questionService;

    public function __construct(TopicRepository $topicRepository, QuestionService $questionService)
    {
        $this->topicRepository = $topicRepository;
        $this->questionService = $questionService;
    }

    /**
     * @Route(name="index", path="/", methods={"GET"})
     */
    public function index() : Response
    {
        return $this->render('index.html.twig', ['topics' => $this->topicRepository->findAllLabels()]);
    }

    /**
     * @Route(name="next_question", path="/next", methods={"POST"})
     * @param Request $req
     * @return Response
     */
    public function ajaxNextQuestion(Request $req) : Response
    {
        /** @var resource|string $content */
        if (!$content = $req->getContent()) {
            throw new BadRequestHttpException('No payload!');
        }

        /** @var array $data */
        $data = json_decode($content, true);
        return new JsonResponse($this->questionService->generateNextQuestion($data['t'], $data['ids']));
    }

    /**
     * @Route(name="evaluate_question", path="/eval", methods={"POST"})
     * @param Request $req
     * @return Response
     */
    public function ajaxEvalQuestion(Request $req) : Response
    {
        /** @var resource|string $content */
        if (!$content = $req->getContent()) {
            throw new BadRequestHttpException('No payload!');
        }

        /** @var array $data */
        $data = json_decode($content, true);
        return new JsonResponse([
            'message' => $this->questionService->evaluateQuestion($data['question'], $data['answers'])
        ]);
    }
}